﻿/// Copyright 2022
/// Crystal Universe Software Inc.
/// All Rights Reserved

using System;
using System.Diagnostics;
using System.Collections.Generic;
using System.Windows.Forms;
using RDPCrystalEDILibraryDemo;
using RDPCrystalEDILibrary_Demo.UserControls;

namespace RDPCrystalEDILibrary_Demo
{
    public partial class Main : RDPDemoForm
    {
        public Main()
        {
            InitializeComponent();

            RDPCrystalEDILibrary.PackageLicense.Key = "Enter serial number here";
            RDPCrystalEDILibrary.PrinterForms.PackageLicense.Key = "Enter serial number here";
        }

        private Dictionary<string, Func<UserControl>> controls = new Dictionary<string, Func<UserControl>>()
        {
            { "  5010 837P - Validate And Load", ()=>new ValidateUserControl("EDIFiles\\Sample_5010_837P.txt","ValidationRules\\Rules_5010_837P_005010X222A1.Rules") },
            { "  5010 834  - Validate And Load", ()=>new ValidateUserControl("EDIFiles\\Sample_5010_834.txt", "ValidationRules\\Rules_5010_834_005010X220A1.Rules") },
            { "  5010 270  - Validate And Load", ()=>new ValidateUserControl("EDIFiles\\Sample_5010_270.txt", "ValidationRules\\Rules_5010_270_005010X279A1.Rules") },
            { "  5010 837P - Save To Database", ()=>new Save_5010_837P_To_Database() },
            { "  5010 837I - Save To Database", ()=>new Save_5010_837I_To_Database() },
            { "  5010 837D - Save To Database", ()=>new Save_5010_837D_To_Database() },
            { "  5010 837P - Create EDI File with TypedDocument",()=>new Create_5010_837P_File() },
            { "  5010 835 - Create EDI File with TypedDocument",()=>new Create_5010_835_File() },
            { "  5010 - Create EDI File With TypedDocument",()=>new Create_General_Document() },
            { "  5010 270  - Create EDI File With TypedDocument", ()=>new Create_5010_270_File() },
            { "  4010 856 - Create EDI File With EDI Document", ()=>new Create_4010_856_File() },
            { "  4010 - Generate 997 Acknowledgement",()=>new ValidateUserControl("EDIFiles\\Sample_4010_837P_FAIL.txt","ValidationRules\\Rules_4010_837P_004010X098A1.Rules",false,true)},
            { "  5010 - Generate 999 Acknowledgement",()=>new ValidateUserControl("EDIFiles\\Sample_5010_837P_FAIL.txt","ValidationRules\\Rules_5010_837P_005010X222A1.Rules",true,true)},
            { "  5010 837P - Load Into UI",()=> new Load_5010_837P_File() },
            { "  5010 835 - Load Into UI",()=>new Load_5010_835_File() },
            { "  4010 810 - Load Into UI",()=>new Load_4010_810_File() },
            { "  4010 835- Load EDI From String Into UI",()=>new Load_4010_835_File() },
            { "  4010 835 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_835.txt","ValidationRules\\Rules_4010_835_004010X091A1.Rules",false) },
            { "  5010 837I - Validate with Code Conditions",()=>new ValidateUserControl("EDIFiles\\Sample_5010_837I.txt","ValidationRules\\Rules_5010_837I_005010X223A2_WithCodeConditions.Rules") },
            { "  5010 834 - Load Into UI",()=>new Load_5010_834_File() },
            { "  4010 837P - Load Into UI With TypedDocument",()=>new Load_4010_837P_With_TypedDocuments() },
            { "  4010 834 - Combine Two Files", ()=>new Join_EDI_Files() },
            { "  4010 837P - Split EDI File",()=>new Split_EDI_File() },
            { "  5010 835 - Split File By NPI",()=>new Split_5010_835_By_NPI() },
            { "  Prebuilt ValidationUnit User Control", ()=>new Validation_Unit() },
            { "  Parse And Load X12 Data/File",()=>new Load_Any_X12_File() },
            { "  CMS 1500 Claim Printing", ()=>new CMS_1500_Printer() },
            { "  5010 837P - Create From CMS-1500 Fields",()=>new Create_5010_837P_From_HCFA_Fields() },
            { "  CMS 1500 From 5010 837P",()=>new CMS1500_From_5010_837P() },
            { "  View EDI Validation Rules",()=>new View_EDI_Rules() },
            { "  Extending Typed Documents For Custom Segments",()=>new Extending_TypedDocuments() },
            { "  Scrub EDI Files ( Hide Sensitive Data )",()=>new Scrubing_EDI_Files() },
            { "  X12 - Line Parser",()=>new Line_Parser() },
            { "  4010 214 - Validate And Load", ()=>new ValidateUserControl("EDIFiles\\Sample_4010_214.txt","ValidationRules\\Rules_4010_214_004010.Rules",false)},
            { "  4010 810 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_810.txt","ValidationRules\\Rules_4010_810_004010.Rules",false)},
            { "  4010 811 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_811.txt","ValidationRules\\Rules_4010_811_004010.Rules",false)},
            { "  4010 850 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_850.txt","ValidationRules\\Rules_4010_850_004010.Rules",false)},
            { "  4010 856 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_856.txt","ValidationRules\\Rules_4010_856_004010.Rules",false)},
            { "  4010 875 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_875.txt","ValidationRules\\Rules_4010_875_004010.Rules",false)},
            { "  4010 990 - Validate And Load",()=>new ValidateUserControl("EDIFiles\\Sample_4010_990.txt","ValidationRules\\Rules_4010_990_004010.Rules",false)},
            { "  Find EDI Specifications",()=>new Find_Specifications() }
        };

        private void lbSamples_SelectedIndexChanged(object sender, EventArgs e)
        {
            pnlContainer.Controls.Clear();
            UserControl control = controls[lbSamples.SelectedItem.ToString()]();
            control.Dock = DockStyle.Fill;
            control.BringToFront();
            pnlContainer.Controls.Add(control);
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
           Process.Start("http://www.rdpcrystal.com/documentation/");
        }

        private void lnkRDP_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/rdpscript/");
        }

        private void lnkAll_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/edi-sdk/");
        }
    }
}
