﻿using System;
using System.Diagnostics;
using System.Windows.Forms;
using RDPCrystalEDILibrary.PrinterForms;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    public partial class CMS_1500_Printer : UserControl
    {
        CMS1500Form cmsForm = new CMS1500Form();

        public CMS_1500_Printer()
        {
            InitializeComponent();

            cmsForm.Data.Add(GenerateTestData());
            cmsForm.Data.Add(GenerateTestData());

            cmsForm.BeforePrint += new EventHandler<FormEventArgs>(cmsForm_BeforePrint);

            printDialog.Document = cmsForm.PrintDocument;
            printPreviewDialog.Document = cmsForm.PrintDocument;
            pageSetupDialog.Document = cmsForm.PrintDocument;

            ppc.Document = cmsForm.PrintDocument;
        }

        private void btnPrintDialog_Click(object sender, EventArgs e)
        {
            printDialog.ShowDialog();
        }

        private void btnPrintPreview_Click(object sender, EventArgs e)
        {
            printPreviewDialog.ShowDialog();
        }

        private void btnPageSetup_Click(object sender, EventArgs e)
        {
            pageSetupDialog.ShowDialog();
        }

        private void btnPrint_Click(object sender, EventArgs e)
        {
            cmsForm.Print();

            //Or save it to an image
            //var blank = new Bitmap(816, 1056);

            //blank.SetResolution(300, 300);
            //Graphics g = Graphics.FromImage(blank);
            //g.Clear(Color.White);

            //////set the margins for the image
            //cmsForm.ImageX = 0.2f;
            //cmsForm.ImageY = 0.2f;

            //var cmsImage = cmsForm.PrintToImage(blank);

            //cmsImage.Save("CMS1500.bmp", System.Drawing.Imaging.ImageFormat.Bmp);
        }

        private void cmsForm_BeforePrint(object sender, FormEventArgs e)
        {
            //e.Cells has all fields that will e send to printer
        }

        private CMSFormData GenerateTestData()
        {
            CMSFormData cmsData = new CMSFormData();

            cmsData.BoxHeader = "All Practice" + Environment.NewLine + "New York";
            cmsData.Box1A = true;
            cmsData.Box1Aa = "Insured ID Number";
            cmsData.Box2 = "Jane Doe";
            cmsData.Box3A = DateTime.Today;
            cmsData.Box3C = true;
            cmsData.Box4 = "Same As Patient";
            cmsData.Box5A = "123 Washington Avenue";
            cmsData.Box5B = "SpringField";
            cmsData.Box5C = "IL";
            cmsData.Box5D = "12345";
            cmsData.Box5E = "2122323321";
            cmsData.Box6A = true;
            cmsData.Box7A = "Same";
            cmsData.Box10Ab = true;
            cmsData.Box10Bb = true;
            cmsData.Box10Cb = true;
            cmsData.Box11 = "99999";
            cmsData.Box11A = DateTime.Today;
            cmsData.Box11Ac = true;
            cmsData.Box11Db = true;
            cmsData.Box12A = "PATIENT SIGNATURE ON FILE";
            cmsData.Box13 = "SINGATURE ON FILE";
            cmsData.Box14A = DateTime.Today;
            cmsData.Box15B = DateTime.Today;
            cmsData.Box16A = DateTime.Today;
            cmsData.Box16B = DateTime.Today;
            cmsData.Box17 = "Doctor Smith";
            cmsData.Box17B = "12345";
            cmsData.Box18A = DateTime.Today;
            cmsData.Box18B = DateTime.Today;
            cmsData.Box20Aa = true;
            cmsData.Box20B = 12342;
            cmsData.Box21A = "90210";
            cmsData.Box21B = "90211";
            cmsData.Box21C = "90212";
            cmsData.Box21D = "90213";
            cmsData.Box23 = "None";
            cmsData.Box25A = "123-12-3334";
            cmsData.Box25C = true;
            cmsData.Box26 = "9383333";
            cmsData.Box27A = true;
            cmsData.Box28 = 1024;
            cmsData.Box29 = 456;
            cmsData.Box30 = null;
            cmsData.Box32 = "742 Evergreen Terrace" + Environment.NewLine + "Springfield IL 9999";
            cmsData.Box32A = "99999";
            cmsData.Box33 = "Joe Doe Therapy" + Environment.NewLine + "Springfield IL 9999";
            cmsData.Box33A = "99999";
            cmsData.Box33C = "1233233333";

            //Service lines
            Box24 box24 = new Box24();
            box24.Box24Aa = DateTime.Today;
            box24.Box24Ab = DateTime.Today;
            box24.Box24B = "11";
            box24.Box24D = "99990";
            box24.Box24Mod1 = "AH";
            box24.Box24Mod2 = "AH";
            box24.Box24Mod3 = "AH";
            box24.Box24Mod4 = "AH";
            box24.Box24E = "1";
            box24.Box24F = 125;
            box24.Box24G = "1";
            cmsData.Box24.Add(box24);

            return cmsData;
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/cms1500form/");
        }
    }
}
