﻿using System;
using System.Diagnostics;
using System.Windows.Forms;
using RDPCrystalEDILibrary;
using RDPCrystalEDILibrary.Docs.x5010;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    public partial class Create_5010_270_File : UserControl
    {
        /// <summary>
        /// #PROJECT DESCRIPTION
        /// Demonstrate how to create a 5010 270 EDI document using a Typed5010Document
        /// and display the new document in the EDIDocumentViewer component
        /// 
        /// #TECHNICAL SUPPORT
        /// Please contact us at support@rdpcrystal.com. Our support team can help answer your questions
        /// </summary>

        private EDIFileLoader ediFileLoader = new EDIFileLoader();

        public Create_5010_270_File()
        {
            InitializeComponent();
        }

        private void btnCreateEDIFile_Click(object sender, EventArgs e)
        {
            try
            {
                //Create a Typed 5010 Document
                Typed5010Document doc270 = new Typed5010Document();

                //Places the correct number of segments in X12 SE segment
                doc270.AutoPlaceCorrectNumOfSegments = true;
                doc270.AutoPlaceNumOfTransactions = true;
                doc270.AutoPlaceNumOfFunctionalGroups = true;
                //Makes sure the ISA element values are the correct length
                doc270.PadISAElementValues = true;

                DocumentLoop interchangeHeader = doc270.MainSection.CreateLoop("Interchange Header");

                ISA isa = interchangeHeader.CreateSegment<ISA>();
                isa.AuthorizationInformationQualifier = "00";
                isa.AuthorizationInformation = "";
                isa.SecurityInformationQualifier = "00";
                isa.SecurityInformation = "";
                isa.InterchangeIDQualifier1 = "ZZ";
                isa.InterchangeSenderID = "SenderID";
                isa.InterchangeIDQualifier2 = "ZZ";
                isa.InterchangeReceiverID = "ReceiverID";
                isa.InterchangeDate = "030101";
                isa.InterchangeTime = "1253";
                isa.RepetitionSeparator = "^";
                isa.InterchangeControlVersionNumber = "00501";
                isa.InterchangeControlNumber = "000000905";
                isa.AcknowledgmentRequested = "1";
                isa.InterchangeUsageIndicator = "T";
                isa.ComponentElementSeparator = ":";

                //Create the function header section
                DocumentLoop functionalHeader = interchangeHeader.CreateLoop("Functional Header");

                GS gs = functionalHeader.CreateSegment<GS>();
                gs.FunctionalIdentifierCode = "HS";
                gs.ApplicationSenderCode = "ApplicationSenderCode";
                gs.ApplicationReceiverCode = "ApplicationReceiverCode";
                gs.Date = "20150303";
                gs.Time = "1424";
                gs.GroupControlNumber = "1234";
                gs.ResponsibleAgencyCode = "X";
                gs.VersionReleaseIndustryIdentifierCode = "005010X279";

                //Create a transaction header loop
                DocumentLoop transactionHeader = functionalHeader.CreateLoop("Transaction Header");
                // ST*270*1234*005010X279~
                ST st = transactionHeader.CreateSegment<ST>();
                st.TransactionSetIdentifierCode = "270";
                st.TransactionSetControlNumber = "1234";
                st.ImplementationConventionReference = "005010X279";

                //BHT*0022*13*10001234*20060501*1319~
                BHT bht = transactionHeader.CreateSegment<BHT>();
                bht.HierarchicalStructureCode = "0022";
                bht.TransactionSetPurposeCode = "13";
                bht.ReferenceIdentification = "10001234";
                bht.Date = "20060501";
                bht.Time = "1319";

                DocumentLoop loop2000A = transactionHeader.CreateLoop("INFORMATION SOURCE LEVEL");
                //HL*1**20*1~
                HL hl = loop2000A.CreateSegment<HL>();
                hl.HierarchicalIDNumber = "1";
                hl.HierarchicalLevelCode = "20";
                hl.HierarchicalChildCode = "1";

                DocumentLoop loop2100A = loop2000A.CreateLoop("INFORMATION SOURCE NAME");

                //NM1*PR*2*ABC COMPANY*****PI*842610001~
                NM1 nm1 = loop2100A.CreateSegment<NM1>();
                nm1.EntityIdentifierCode = "PR";
                nm1.EntityTypeQualifier = "2";
                nm1.NameLastOrOrganizationName = "ABC COMPANY";
                nm1.IdentificationCodeQualifier = "PI";
                nm1.IdentificationCode = "842610001";

                DocumentLoop loop2000B = transactionHeader.CreateLoop("INFORMATION RECEIVER LEVEL");
                //HL*1**20*1~
                HL hl2000B = loop2000B.CreateSegment<HL>();
                hl2000B.HierarchicalIDNumber = "2";
                hl2000B.HierarchicalParentIDNumber = "1";
                hl2000B.HierarchicalLevelCode = "20";
                hl2000B.HierarchicalChildCode = "1";

                DocumentLoop loop2100B = loop2000B.CreateLoop("INFORMATION RECEIVER NAME");

                //NM1*1P*2*BONE AND JOINT CLINIC*****SV*2000035~
                NM1 nm1loop2100B = loop2100B.CreateSegment<NM1>();
                nm1loop2100B.EntityIdentifierCode = "1P";
                nm1loop2100B.EntityTypeQualifier = "2";
                nm1loop2100B.NameLastOrOrganizationName = "BONE AND JOINT CLINIC";
                nm1loop2100B.IdentificationCodeQualifier = "SV";
                nm1loop2100B.IdentificationCode = "2000035";

                DocumentLoop loop2000C = transactionHeader.CreateLoop("SUBSCRIBER LEVEL");
                //HL*3*2*22*0~
                HL hl2000C = loop2000C.CreateSegment<HL>();
                hl2000C.HierarchicalIDNumber = "3";
                hl2000C.HierarchicalParentIDNumber = "2";
                hl2000C.HierarchicalLevelCode = "23";
                hl2000C.HierarchicalChildCode = "0";

                //TRN*1*93175-012547*9877281234~
                TRN trn = loop2000C.CreateSegment<TRN>();
                trn.TraceTypeCode = "1";
                trn.ReferenceIdentification1 = "93175-012547";
                trn.OriginatingCompanyIdentifier = "9877281234";

                DocumentLoop loop2100C = loop2000C.CreateLoop("SUBSCRIBER NAME");

                //NM1*IL*1*SMITH*ROBERT****MI*11122333301~
                NM1 nm1loop2100C = loop2100C.CreateSegment<NM1>();
                nm1loop2100C.EntityIdentifierCode = "1L";
                nm1loop2100C.EntityTypeQualifier = "1";
                nm1loop2100C.NameLastOrOrganizationName = "SMITH";
                nm1loop2100C.FirstName = "ROBERT";
                nm1loop2100C.IdentificationCodeQualifier = "MI";
                nm1loop2100C.IdentificationCode = "11122333301";

                //DMG*D8*19430519~
                DMG dmg = loop2100C.CreateSegment<DMG>();
                dmg.DateTimePeriodFormatQualifier = "D8";
                dmg.DateTimePeriod = "19430519";

                //DTP*291*D8*20060501~
                DTP dtp = loop2100C.CreateSegment<DTP>();
                dtp.DateTimeQualifier = "291";
                dtp.DateTimePeriodFormatQualifier = "D8";
                dtp.DateTimePeriod = "20060501";

                DocumentLoop loop2110C = loop2100C.CreateLoop("SUBSCRIBER ELIGIBILITY OR BENEFIT INQUIRY");

                //EQ*30~
                EQ eq = loop2110C.CreateSegment<EQ>();
                eq.ServiceTypeCode = "30";

                //Create the end of the transaction (SE segment). This must be done in a loop.
                DocumentLoop endOfTransactionLoop = transactionHeader.CreateLoop("End Of Transaction");
                SE se = endOfTransactionLoop.CreateSegment<SE>();
                se.TransactionSetControlNumber = "1";

                //Create the end of the functional group (GE segment). This must be done in a loop.
                DocumentLoop endOfFunctionalGroupLoop = functionalHeader.CreateLoop("End Functional Group");
                GE ge = endOfFunctionalGroupLoop.CreateSegment<GE>();
                ge.GroupControlNumber = "11234";

                //Finally create the end of the interchange loop (IEA segment). This must be done in a loop.
                DocumentLoop endInterchangeSection = interchangeHeader.CreateLoop("End Interchange");
                IEA iea = endInterchangeSection.CreateSegment<IEA>();
                iea.InterchangeControlNumber = "123";

                txtFile.Text = doc270.ToEDIString(new Delimiters());

                //Display the new document
                ediFileLoader.EDIDataString = txtFile.Text;
                ediDocumentViewer.LoadDocument(ediFileLoader.Load());
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/products/edi-library/typed-document/");
        }
    }
}
