﻿using System;
using System.Diagnostics;
using System.Collections.Generic;
using System.Windows.Forms;
using RDPCrystalEDILibrary;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    /// <summary>
    /// #PROJECT DESCRIPTION
    /// Demonstrates how to extend TypedDocument to create custom documents and custom segments
    /// 
    /// #TECHNICAL SUPPORT
    /// Please contact us at support@rdpcrystal.com. Our support team can help answer your questions
    /// </summary>
    public partial class Extending_TypedDocuments : UserControl
    {
        private EDIFileLoader ediFileLoader = new EDIFileLoader();

        public Extending_TypedDocuments()
        {
            InitializeComponent();
        }

        private void btnCreateEDIFile_Click(object sender, EventArgs e)
        {
            try
            {
                MyTypedDocument customDocument = new MyTypedDocument();

                DocumentLoop mainLoop = customDocument.MainSection.CreateLoop("Header");

                CustomSegment1 cs1 = mainLoop.CreateSegment<CustomSegment1>();
                cs1.ID = "ID123";
                cs1.Name = "John Smith";

                CustomSegment2 cs2 = mainLoop.CreateSegment<CustomSegment2>();
                cs2.SocialSecurity = "123-12-1222";
                cs2.Age = "38";

                for (int i = 0; i < 10; i++)
                {
                    DocumentLoop dataLoop = mainLoop.CreateLoop("Data");
                    CustomSegment3 cs3 = dataLoop.CreateSegment<CustomSegment3>();
                    cs3.City = "New York";
                    cs3.State = "NY";
                    cs3.Zip = "111" + i;
                    cs3.DiagnosisCodes.DiagnosisCodePointer1 = i.ToString();
                    cs3.DiagnosisCodes.DiagnosisCodePointer2 = i.ToString();
                    cs3.DiagnosisCodes.DiagnosisCodePointer3 = i.ToString();
                    cs3.DiagnosisCodes.DiagnosisCodePointer4 = i.ToString();
                }

                txtFile.Text = customDocument.ToEDIString(new Delimiters());

                //Display the new segments
                ediFileLoader.EDIDataString = txtFile.Text;
                ediDocumentViewer.LoadDocument(ediFileLoader.Load());
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/products/edi-library/typed-document/");
        }
    }

    public class MyTypedDocument : TypedDocument
    {
        public MyTypedDocument()
        {
        }

        /// <summary>
        /// This method is only called when you are loading this document from an EDILightWeightDocument
        /// </summary>
        /// <param name="segmentName"></param>
        /// <returns></returns>
        protected override DocumentSegment GetDocumentSegment(string segmentName)
        {
            switch (segmentName)
            {
                case "CS1":
                    {
                        return new CustomSegment1();
                    }
                case "CS2":
                    {
                        return new CustomSegment2();
                    }
                case "ABC":
                    {
                        return new CustomSegment3();
                    }
            }

            return null;
        }
    }

    public class CustomSegment1 : DocumentSegment
    {
        public CustomSegment1()
        {
            Name = "CS1";
        }

        public string ID { get; set; }
        public string RefID { get; set; }

        public override void Write(WriteArguments w)
        {
            base.Write(w);

            w.Values.Add(Name);
            w.Values.Add(ID);
            w.Values.Add(RefID);

            WriteToBuffer(w);
        }

        public override void Load(LightWeightSegment segment)
        {
            for (int i = 0; i < segment.Elements.Count; i++)
            {
                LightWeightElement element = segment.Elements[i];

                switch (i)
                {
                    case 0:
                        {
                            ID = GetValue(element);
                            break;
                        }
                    case 1:
                        {
                            RefID = GetValue(element);
                            break;
                        }
                }
            }
        }
    }

    public class CustomSegment2 : DocumentSegment
    {
        public CustomSegment2()
        {
            Name = "CS2";
        }

        public string SocialSecurity { get; set; }
        public string Age { get; set; }

        public override void Write(WriteArguments w)
        {
            base.Write(w);

            w.Values.Add(Name);
            w.Values.Add(SocialSecurity);
            w.Values.Add(Age);

            WriteToBuffer(w);
        }

        public override void Load(LightWeightSegment segment)
        {
            for (int i = 0; i < segment.Elements.Count; i++)
            {
                LightWeightElement element = segment.Elements[i];

                switch (i)
                {
                    case 0:
                        {
                            SocialSecurity = GetValue(element);
                            break;
                        }
                    case 1:
                        {
                            Age = GetValue(element);
                            break;
                        }
                }
            }
        }
    }

    public class CustomSegment3 : DocumentSegment
    {
        public CustomSegment3()
        {
            Name = "ABC";

            DiagnosisCodes = new CustomCompositeElement();
        }

        public string City { get; set; }
        public string State { get; set; }
        public string Zip { get; set; }
        public CustomCompositeElement DiagnosisCodes { get; set; }

        public override void Write(WriteArguments w)
        {
            base.Write(w);

            w.Values.Add(Name);
            w.Values.Add(City);
            w.Values.Add(State);
            w.Values.Add(Zip);
            w.Values.Add(DiagnosisCodes.GetString(w.Delimiters.CompositeTerminatorCharacter));

            WriteToBuffer(w);
        }

        public override void Load(LightWeightSegment segment)
        {
            for (int i = 0; i < segment.Elements.Count; i++)
            {
                LightWeightElement element = segment.Elements[i];

                switch (i)
                {
                    case 0:
                        {
                            City = GetValue(element);
                            break;
                        }
                    case 1:
                        {
                            State = GetValue(element);
                            break;
                        }
                    case 2:
                        {
                            Zip = GetValue(element);
                            break;
                        }
                    case 4:
                        {
                            if (element.Composite && element.Elements != null)
                            {
                                for (int j = 0; j < element.Elements.Count; j++)
                                {
                                    LightWeightElement celement = element.Elements[j];

                                    switch (j)
                                    {
                                        case 0:
                                            {
                                                DiagnosisCodes.DiagnosisCodePointer1 = GetValue(celement);
                                                break;
                                            }
                                        case 1:
                                            {
                                                DiagnosisCodes.DiagnosisCodePointer2 = GetValue(celement);
                                                break;
                                            }
                                        case 2:
                                            {
                                                DiagnosisCodes.DiagnosisCodePointer3 = GetValue(celement);
                                                break;
                                            }
                                        case 3:
                                            {
                                                DiagnosisCodes.DiagnosisCodePointer4 = GetValue(celement);
                                                break;
                                            }
                                    }
                                }
                            }
                            break;
                        }
                }
            }
        }
    }

    public class CustomCompositeElement : DocumentCompositeElement
    {
        public string DiagnosisCodePointer1 { get; set; }
        public string DiagnosisCodePointer2 { get; set; }
        public string DiagnosisCodePointer3 { get; set; }
        public string DiagnosisCodePointer4 { get; set; }

        public override string GetString(char compElemSep)
        {
            List<string> e = new List<string>();

            e.Add(DiagnosisCodePointer1);
            e.Add(DiagnosisCodePointer2);
            e.Add(DiagnosisCodePointer3);
            e.Add(DiagnosisCodePointer4);

            return Write(compElemSep, e);
        }
    }
}
