﻿using System;
using System.Diagnostics;
using System.Collections.Generic;
using System.IO;
using System.Windows.Forms;
using RDPCrystalEDILibrary;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    /// <summary>
    /// #PROJECT DESCRIPTION
    /// Demonstrates how to join 2 EDI files at the ST Transaction and at the GS Functional Group Level using the EDIFileJoiner component
    /// 
    /// #TECHNICAL SUPPORT
    /// Please contact us at support@rdpcrystal.com. Our support team can help answer your questions
    /// </summary>
    public partial class Join_EDI_Files : UserControl
    {
        private EDIFileLoader ediFileLoader = new EDIFileLoader();

        public Join_EDI_Files()
        {
            InitializeComponent();
        }

        private void btnCombine_Click(object sender, EventArgs e)
        {
            EDIFileJoiner joiner = new EDIFileJoiner();

            //Join at the ST Transaction Level
            joiner.FileJoinLevel = FileJoinLevel.HEADER;
            joiner.EachSegmentInNewLine = true;

            joiner.OnFileOperationCompleted += new EventHandler<FileOperationCompletedEventArgs>(joiner_OnFileOperationCompleted);

            List<string> files = new List<string>();
            files.Add("EDIFiles/Sample_4010_834_For_Combine1.txt");
            files.Add("EDIFiles/Sample_4010_834_For_Combine2.txt");

            try
            {
                joiner.JoinAsync(files, "CombinedAll.txt");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void btnCombineGroup_Click(object sender, EventArgs e)
        {
            EDIFileJoiner joiner = new EDIFileJoiner();
            joiner.FileJoinLevel = FileJoinLevel.FUNCTIONALGROUP;
            joiner.EachSegmentInNewLine = true;

            joiner.OnFileOperationCompleted += new EventHandler<FileOperationCompletedEventArgs>(joiner_OnFileOperationCompleted);

            List<string> files = new List<string>();

            files.Add("EDIFiles/Sample_4010_834_For_Combine1.txt");
            files.Add("EDIFiles/Sample_4010_834_For_Combine2.txt");

            try
            {
                joiner.JoinAsync(files, "CombinedAll.txt");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void joiner_OnFileOperationCompleted(object sender, FileOperationCompletedEventArgs e)
        {
            if (e.Status != FileOperationStatus.Success)
            {
                MessageBox.Show("Error combining files",  "RDPCrystal EDI Library");
            }
            else if (e.Status == FileOperationStatus.Success)
            {
                this.Invoke(new Action(() =>
                {
                    txtEDIFile.Text = File.ReadAllText("CombinedAll.txt");

                    //Display the new segments
                    ediFileLoader.EDIDataString = txtEDIFile.Text;
                    ediDocumentViewer.LoadDocument(ediFileLoader.Load());
                }));
            }
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/products/edi-library/edi-file-joiner/");
        }
    }
}
