﻿using System;
using System.IO;
using System.Diagnostics;
using System.Windows.Forms;
using RDPCrystalEDILibrary;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    /// <summary>
    /// #PROJECT DESCRIPTION
    /// Demonstrates how to scrub (hide) sensitive data in an EDI document using the EDIFileScrubber component
    /// 
    /// #TECHNICAL SUPPORT
    /// Please contact us at support@rdpcrystal.com. Our support team can help answer your questions
    /// </summary>
    public partial class Scrubing_EDI_Files : UserControl
    {
        private EDIFileScrubber ediFileScrubber = new EDIFileScrubber();

        public Scrubing_EDI_Files()
        {
            InitializeComponent();

            txtFile.Text = File.ReadAllText("EDIFiles\\Sample_5010_837P.txt");
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            try
            {
                //Replace the first 4 elements of the ISA segment with the letter 'Q'
                ScrubRule isaRule = new ScrubRule();
                isaRule.SegmentName = "ISA";
                isaRule.ReplaceCharacter = 'Q';
                isaRule.ScrubPositions.Add(new ScrubPosition(0));
                isaRule.ScrubPositions.Add(new ScrubPosition(1));
                isaRule.ScrubPositions.Add(new ScrubPosition(2));
                isaRule.ScrubPositions.Add(new ScrubPosition(3));

                //Replace the first composite element on the SVC segment with the letter 'W'
                ScrubRule svcRule = new ScrubRule();
                svcRule.SegmentName = "SVC";
                svcRule.ReplaceCharacter = 'W';
                svcRule.ScrubPositions.Add(new ScrubPosition(0, 0));

                ediFileScrubber.ScrubRules.Add(isaRule);
                ediFileScrubber.ScrubRules.Add(svcRule);

                ediFileScrubber.EDIDataString = txtFile.Text;

                EDILightWeightDocument doc = ediFileScrubber.Scrub();
                txtScrubbedFile.Text = doc.GenerateEDIData();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/products/edi-library/edifilescrubber/");
        }
    }
}
