﻿using System;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;
using RDPCrystalEDILibrary;

namespace RDPCrystalEDILibrary_Demo.UserControls
{
    /// <summary>
    /// #PROJECT DESCRIPTION
    /// Demonstrates how to split an EDI document at the ST Transaction Level with the EDIFileSplitter component
    /// 
    /// #TECHNICAL SUPPORT
    /// Please contact us at support@rdpcrystal.com. Our support team can help answer your questions
    /// </summary>
    public partial class Split_EDI_File : UserControl
    {
        public Split_EDI_File()
        {
            InitializeComponent();

            txtFile.Text = File.ReadAllText("EDIFiles\\Sample_4010_837P_For_Split.txt");
        }

        private void btnCombile_Click(object sender, EventArgs e)
        {
            EDIFileSplitter ediFileSplitter = new EDIFileSplitter();

            //Split at the ST Transaction Level
            ediFileSplitter.FileSplitLevel = FileSplitLevel.HEADER;
            ediFileSplitter.SplitFileExtension = ".edi";
            ediFileSplitter.NumberOfItemsPerFile = 2;
            ediFileSplitter.OutputFilename = "MySplitFile";

            ediFileSplitter.OnFileOperationCompleted += new EventHandler<FileOperationCompletedEventArgs>(joiner_OnFileOperationCompleted);

            try
            {
                string currentDirectory = Directory.GetCurrentDirectory();
                ediFileSplitter.Split("EDIFiles\\Sample_4010_837P_For_Split.txt", currentDirectory);

                txtFile1.Text = File.ReadAllText("MySplitFile1.edi");
                txtFile2.Text = File.ReadAllText("MySplitFile2.edi");
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "RDPCrystal EDI Library");
            }
        }

        private void joiner_OnFileOperationCompleted(object sender, FileOperationCompletedEventArgs e)
        {
            if (e.Status != FileOperationStatus.Success)
            {
                MessageBox.Show("Error splitting file", "RDPCrystal EDI Library");
            }
            else if (e.Status == FileOperationStatus.Success)
            {
                MessageBox.Show("The following files were created\n" + String.Join(",", e.SplitFiles), "File Split Success");
            }
        }

        private void lnk_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://www.rdpcrystal.com/products/edi-library/edi-file-splitter/");
        }
    }
}
